@@ -169,7 +169,7 @@ sub unique_id {
 
   my @cols = $row->result_source->columns;
   my %data = $row->get_columns;
-  my @vals = %data{@cols};
+  my @vals = @data{@cols};
   return ref($row) . join(',',@cols) . join(',',map {$_//''} @vals);
 }
 
